#!/bin/sh

# Create Root CA private key and certificate

set -e

CA_HOME=$(cd "$(dirname "$0")" >/dev/null && pwd)
CA_CERTS=${CA_HOME}/certs
CA_PRIVATE=${CA_HOME}/private


# default certificate lifetime
days=5475

# Check command line options
for option in "$@"
do
    case "${option}" in
            --days=*)  days=$(echo "${option}" | sed 's/--days=//' | sed 's/^"//' | sed 's/"$//' | sed 's/^\(.*\)\/$/\1/')
                       ;;
            *)         >&2 echo "unknown option: ${option}, use --dns="
                       exit 1
                       ;;
    esac
done


mkdir -p "${CA_CERTS}" "${CA_PRIVATE}"

echo "step 1: Generate Certificate Authority (CA) Private Key"
openssl ecparam -name prime256v1 -genkey -noout -out "${CA_PRIVATE}"/root-ca.key

echo "step 2: Generate Certificate Authority Certificate"
openssl req -new -x509 -sha256 -days ${days} -key "${CA_PRIVATE}"/root-ca.key -out "${CA_CERTS}"/root-ca.crt

